@@ -320,7 +320,7 @@ class TelegramSession:
             return value
         raise KeyError("'{0}' is not found".format(field))
 
-    def set(self, field: str, value) -> bool:
+    def set(self, field: str, value):
         self._local_data[field] = value
 
     def __setitem__(self, field: str, value):
